@@ -53,6 +53,7 @@ static void usage()
 
 		 "--domainname new_domainname\n"
 		 "\tSet the domainname (NIS) in the new security context.\n"
+		 "\tUse \"none\" to unset the domain name.\n"
 
 		 "--flag\n"
 		 "\tSet one flag in the new or current security context. The following\n"
@@ -131,6 +132,8 @@ int main (int argc, char *argv[])
 			}else if (strcmp(opt,"fakeinit")==0){
 				fakeinit = 1;
 				flags |= 16;
+			}else if (strcmp(opt,"hideinfo")==0){
+				flags |= 32;
 			}else{
 				fprintf (stderr,"Unknown flag %s\n",opt);
 			}
