@@ -1,5 +1,6 @@
 #!/bin/sh
 # Complete the installation of a vserver
+USR_LIB_VSERVER=/usr/lib/vserver
 vserver_mknod()
 {
 	mknod $1 $2 $3 $4
@@ -20,8 +21,8 @@ else
 	vserver_mknod $VROOT/dev/urandom c 1 9 644
 	vserver_mknod $VROOT/dev/tty c 5 0 666
 	vserver_mknod $VROOT/dev/ptmx c 5 2 666
-	test -f /etc/vservers/$1.conf || cp /usr/lib/vserver/sample.conf /etc/vservers/$1.conf
-	test -f /etc/vservers/$1.sh   || cp /usr/lib/vserver/sample.sh /etc/vservers/$1.sh
+	test -f /etc/vservers/$1.conf || cp $USR_LIB_VSERVER/sample.conf /etc/vservers/$1.conf
+	test -f /etc/vservers/$1.sh   || cp $USR_LIB_VSERVER/sample.sh /etc/vservers/$1.sh
 	echo NETWORKING=yes >$VROOT/etc/sysconfig/network
 	echo HOSTNAME=$1 >>$VROOT/etc/sysconfig/network
 	(
@@ -32,7 +33,7 @@ else
 			*.bak|*~|functions|killall|halt|single)
 				;;
 			*)
-				/usr/lib/vserver/capchroot /vservers/$1 /sbin/chkconfig --level 2345 $serv off
+				$USR_LIB_VSERVER/capchroot /vservers/$1 /sbin/chkconfig --level 2345 $serv off
 				;;
 			esac
 		done
@@ -42,7 +43,7 @@ else
 		echo /dev/hdv1	/	ext2	defaults	1	1 >$VROOT/etc/fstab
 		echo /dev/hdv1	/	ext2	rw	1	1 >$VROOT/etc/mtab
 	fi
-	cp -a /usr/lib/vserver/vreboot $VROOT/sbin/.
+	cp -a $USR_LIB_VSERVER/vreboot $VROOT/sbin/.
 	ln -sf vreboot $VROOT/sbin/vhalt
 fi
 
