@@ -15,24 +15,11 @@
 #include <vector>
 #include <list>
 #include <set>
-#include <algorithm>
-#include <iostream.h>
-#include <pfstream.h>
-#include <linux/ext2_fs.h>
 #include "vutil.h"
 
-// Patch to help compile this utility on unpatched kernel source
-#ifndef EXT2_IMMUTABLE_FILE_FL
-	#define EXT2_IMMUTABLE_FILE_FL	0x00000010
-	#define EXT2_IMMUTABLE_LINK_FL	0x00008000
-#endif
-
-
 using namespace std;
 
-extern bool testmode;
 
-static int debug = 0;
 static int  ext2flags = EXT2_IMMUTABLE_FILE_FL | EXT2_IMMUTABLE_LINK_FL;
 static struct {
 	int nblink;
@@ -67,101 +54,7 @@ static void usage()
 		;
 }
 
-class PACKAGE{
-public:
-	string name;
-	string version;	// version + release
-	PACKAGE(string &_name, string &_version)
-		: name (_name), version(_version)
-	{
-	}
-	PACKAGE(const char *_name, const char *_version)
-		: name (_name), version(_version)
-	{
-	}
-	PACKAGE(const string &line)
-	{
-		*this = line;
-	}
-	PACKAGE & operator = (const string &_line)
-	{
-		string line (_line);
-		string::iterator pos = find (line.begin(),line.end(),'=');
-		if (pos != line.end()){
-			name = string(line.begin(),pos);
-			version = string(pos + 1,line.end());
-		}
-		return *this;
-	}
-	bool operator == (const PACKAGE &v) const
-	{
-		return name == v.name && version == v.version;
-	}
-	// Load the file member of the package, but exclude configuration file
-	void loadfiles(const string &ref, set<string> &files)
-	{
-		if (debug > 2) cout << "Loading files for package " << name << endl;
-		string cmd = "| /usr/sbin/chroot " + ref + " /bin/rpm -ql --dump "
-			+ name + "-" + version;
-		ipfstream oo (cmd.c_str());
-		while (1){
-			char tmp[1000];
-			int mode=-1,type=-1;
-			oo.getline (tmp,sizeof(tmp)-1);
-			if (tmp[0] == '\0') break;
-			char *start = tmp;
-			for (int i=0; i<8; i++){
-				char *pt = start;
-				while (*pt > ' ') pt++;
-				if (*pt == ' ') *pt++ = '\0';
-				if (i == 4){
-					sscanf(start,"%o",&mode);
-				}else if (i==7){
-					type = atoi(start);
-				}
-				start = pt;
-					
-			}						
-			if (type == 0 && S_ISREG(mode)){
-				files.insert (tmp);
-			}else if (debug > 10){
-				cout << "Package " << name << " exclude " << tmp << endl;
-			}
-		}
-		if (debug > 2) cout << "Done\n";
-	}
-	#if 0
-	bool locate(const string &path)
-	{
-		return find (files.begin(),files.end(),path) != files.end();
-	}
-	#endif
-};
 
-/*
-	Load the list of all packages in a vserver
-*/
-static void vunify_loadallpkg (string &refserver, list<PACKAGE> &packages)
-{
-	string cmd = "| /usr/sbin/chroot " + refserver + " /bin/rpm -qa"
-		+ " --queryformat \"%{name}=%{version}-%{release}\\n\"";
-	// cout << "command " << cmd << endl;
-	ipfstream oo (cmd.c_str());
-	copy (istream_iterator<string>(oo),istream_iterator<string>()
-		,inserter(packages,packages.begin()));
-}
-
-
-static int vbuild_lstat (string path, struct stat &st)
-{
-	int ret = 0;
-	if (lstat(path.c_str(),&st) == -1){
-		fprintf (stderr,"Can't lstat file %s (%s)\n"
-			,path.c_str(),strerror(errno));
-		ret = -1;
-	}
-	return ret;
-}
 
 static int vbuild_copy (
 	string refserv,
@@ -185,7 +78,7 @@ static int vbuild_copy (
 			}
 			string file = refserv + "/" + ent->d_name;
 			struct stat st;
-			if (vbuild_lstat(file.c_str(),st) == -1){
+			if (vutil_lstat(file.c_str(),st) == -1){
 				ret = -1;
 			}else if (st.st_dev != dev){
 				if (debug > 0) printf ("Ignore sub-directory %s\n",file.c_str());
@@ -296,7 +189,7 @@ int main (int argc, char *argv[])
 		list<PACKAGE> packages;
 		// Load the files which are not configuration files from
 		// the packages
-		vunify_loadallpkg (refserv,packages);
+		vutil_loadallpkg (refserv,packages);
 		set<string> files;
 		for (list<PACKAGE>::iterator it=packages.begin(); it!=packages.end(); it++){
 			(*it).loadfiles(refserv,files);
@@ -306,8 +199,8 @@ int main (int argc, char *argv[])
 		mkdir (newserv.c_str(),0755);
 		// Check if it is on the same volume
 		struct stat refst,newst;
-		if (vbuild_lstat(refserv,refst)!=-1
-			&& vbuild_lstat(newserv,newst)!=1){
+		if (vutil_lstat(refserv,refst)!=-1
+			&& vutil_lstat(newserv,newst)!=1){
 			if (refst.st_dev != newst.st_dev){
 				fprintf (stderr,"Can't vbuild %s because it is not on the same volume as %s\n"
 					,newserv.c_str(),refserv.c_str());
