@@ -16,8 +16,7 @@
 #include <vector>
 #include <list>
 #include <algorithm>
-#include <iostream.h>
-#include <pfstream.h>
+#include <iostream>
 #include "vutil.h"
 
 using namespace std;
@@ -103,40 +102,45 @@ public:
 	{
 		if (files.empty()){
 			if (debug) cout << "Loading files for package " << name << endl;
-			string cmd = "| /usr/sbin/chroot /vservers/" + ref + " /bin/rpm -ql --dump "
+			string cmd = "/usr/sbin/chroot /vservers/" + ref + " /bin/rpm -ql --dump "
 				+ name + "-" + version;
-			ipfstream oo (cmd.c_str());
-			while (1){
+			FILE *fin = popen (cmd.c_str(),"r");
+			if (fin == NULL){
+				fprintf (stderr,"Can't execute %s (%s)\n",cmd.c_str()
+					,strerror(errno));
+			}else{
 				char tmp[1000];
-				int mode=-1,type=-1;
-				oo.getline (tmp,sizeof(tmp)-1);
-				if (tmp[0] == '\0') break;
-				char *start = tmp;
-				for (int i=0; i<8; i++){
-					char *pt = start;
-					while (*pt > ' ') pt++;
-					if (*pt == ' ') *pt++ = '\0';
-					if (i == 4){
-						sscanf(start,"%o",&mode);
-					}else if (i==7){
-						type = atoi(start);
+				while (fgets(tmp,sizeof(tmp)-1,fin)!=NULL){
+					int last = strlen(tmp)-1;
+					if (last >= 0 && tmp[last] == '\n') tmp[last] = '\0';
+					int mode=-1,type=-1;
+					char *start = tmp;
+					for (int i=0; i<8; i++){
+						char *pt = start;
+						while (*pt > ' ') pt++;
+						if (*pt == ' ') *pt++ = '\0';
+						if (i == 4){
+							sscanf(start,"%o",&mode);
+						}else if (i==7){
+							type = atoi(start);
+						}
+						start = pt;
+							
+					}			
+					bool must_unify = false;			
+					if (S_ISREG(mode)){
+						if(type == 0 && !vunify_inside(excldirs,tmp)){
+							must_unify = true;
+						}else if(vunify_inside(incldirs,tmp)){
+							must_unify = true;
+						}
 					}
-					start = pt;
-						
-				}			
-				bool must_unify = false;			
-				if (S_ISREG(mode)){
-					if(type == 0 && !vunify_inside(excldirs,tmp)){
-						must_unify = true;
-					}else if(vunify_inside(incldirs,tmp)){
-						must_unify = true;
+					if (must_unify){
+						files.push_front (tmp);
+					}else if (debug){
+						cout << "Package " << name << " exclude " << tmp << endl;
 					}
 				}
-				if (must_unify){
-					files.push_front (tmp);
-				}else if (debug){
-					cout << "Package " << name << " exclude " << tmp << endl;
-				}
 			}
 			if (debug) cout << "Done\n";
 		}
@@ -170,12 +174,37 @@ template<class T>
 */
 static void vunify_loadallpkg (string &refserver, list<PACKAGE_UNI> &packages)
 {
-	string cmd = "| /usr/sbin/chroot /vservers/" + refserver + " /bin/rpm -qa"
-		+ " --queryformat \"%{name}=%{version}-%{release}\\n\"";
+	string cmd;
+	if (refserver == "/"){
+		cmd = "/bin/rpm -qa"
+			" --queryformat \"%{name}=%{version}-%{release}\\n\"";
+	}else{
+		cmd = "/usr/sbin/chroot /vservers/" + refserver + " /bin/rpm -qa"
+			" --queryformat \"%{name}=%{version}-%{release}\\n\"";
+	}
 	// cout << "command " << cmd << endl;
-	ipfstream oo (cmd.c_str());
-	copy (istream_iterator<string>(oo),istream_iterator<string>()
-		,inserter(packages,packages.begin()));
+	#if 0
+		cmd = "| " + cmd;
+		ipfstream oo (cmd.c_str());
+		copy (istream_iterator<string>(oo),istream_iterator<string>()
+			,inserter(packages,packages.begin()));
+	#else
+		FILE *fin = popen (cmd.c_str(),"r");
+		if (fin == NULL){
+			fprintf (stderr,"Can't execute %s (%s)\n",cmd.c_str()
+				,strerror(errno));
+		}else{
+			char line[1000];
+			while (fgets(line,sizeof(line)-1,fin)!=NULL){
+				// fprintf (stderr,"line: %s",line);
+				int last = strlen(line)-1;
+				if (last >= 0 && line[last] == '\n') line[last] = '\0';
+				packages.push_back (PACKAGE_UNI(line));
+			}
+			pclose (fin);
+			// fprintf (stderr,"Fin\n");
+		}
+	#endif
 }
 
 /*
