@@ -9,7 +9,6 @@
 #include <set>
 #include <algorithm>
 #include <iostream>
-#include <pfstream.h>
 #include <list>
 
 extern int debug;
@@ -56,35 +55,38 @@ public:
 	void loadfiles(const string &ref, set<string> &files)
 	{
 		if (debug > 2) cout << "Loading files for package " << name << endl;
-		string cmd = "| /usr/sbin/chroot " + ref + " /bin/rpm -ql --dump "
+		string cmd = "/usr/sbin/chroot " + ref + " /bin/rpm -ql --dump "
 			+ name + "-" + version;
-		ipfstream oo (cmd.c_str());
-		while (1){
+		FILE *fin = popen (cmd.c_str(),"r");
+		if (fin == NULL){
+			fprintf (stderr,"Can't execute %s (%s)\n",cmd.c_str()
+				,strerror(errno));
+		}else{
 			char tmp[1000];
-			int mode=-1,type=-1;
-			oo.getline (tmp,sizeof(tmp)-1);
-			if (tmp[0] == '\0') break;
-			char *start = tmp;
-			for (int i=0; i<8; i++){
-				char *pt = start;
-				while (*pt > ' ') pt++;
-				if (*pt == ' ') *pt++ = '\0';
-				if (i == 4){
-					sscanf(start,"%o",&mode);
-				}else if (i==7){
-					type = atoi(start);
+			while (fgets(tmp,sizeof(tmp)-1,fin)!=NULL){
+				int last = strlen(tmp)-1;
+				if (last >= 0 && tmp[last] == '\n') tmp[last] = '\0';
+				int mode=-1,type=-1;
+				char *start = tmp;
+				for (int i=0; i<8; i++){
+					char *pt = start;
+					while (*pt > ' ') pt++;
+					if (*pt == ' ') *pt++ = '\0';
+					if (i == 4){
+						sscanf(start,"%o",&mode);
+					}else if (i==7){
+						type = atoi(start);
+					}
+					start = pt;
+						
+				}						
+				if (type == 0 && S_ISREG(mode)){
+					files.insert (tmp);
+				}else if (debug > 10){
+					cout << "Package " << name << " exclude " << tmp << endl;
 				}
-				start = pt;
-					
-			}						
-			if (type == 0 && S_ISREG(mode)){
-				files.insert (tmp);
-			}else if (debug > 10){
-				cout << "Package " << name << " exclude " << tmp << endl;
 			}
 		}
-		int status;
-		wait (&status);
 		if (debug > 2) cout << "Done\n";
 	}
 	#if 0
